@@ -442,6 +442,13 @@ def test_is_windows11_false_win8_1(patched_platform, patched_release):
     patched_platform.assert_called()
     patched_release.assert_called()
 
+@patch("platform.release", return_value="2022Server")
+@patch("platform.system", return_value="Windows")
+def test_is_windows11_false_winserver(patched_platform, patched_release):
+    """Test is_windows11()"""
+    assert is_windows11() is False
+    patched_platform.assert_called()
+    patched_release.assert_called()
 
 @pytest.mark.unit
 @patch("platform.system", return_value="Linux")
@@ -556,7 +563,7 @@ def test_active_ports_on_supported_devices_mac_duplicates_check(mock_platform, m
 def test_message_to_json_shows_all():
     """Test that message_to_json prints fields that aren't included in data passed in"""
     actual = json.loads(message_to_json(mesh_pb2.MyNodeInfo()))
-    expected = { "myNodeNum": 0, "rebootCount": 0, "minAppVersion": 0 }
+    expected = { "myNodeNum": 0, "rebootCount": 0, "minAppVersion": 0, "deviceId": "", "pioEnv": "" }
     assert actual == expected
 
 @pytest.mark.unit
